==> WebService-Fastly-3.04.tar.gz: WebService-Fastly-3.04/docs/BillingResponseLineItem.md <==
# WebService::Fastly::Object::BillingResponseLineItem

## Load the model package
```perl
use WebService::Fastly::Object::BillingResponseLineItem;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_at** | **DateTime** | Date and time in ISO 8601 format. | [optional] [readonly] 
**deleted_at** | **DateTime** | Date and time in ISO 8601 format. | [optional] [readonly] 
**updated_at** | **DateTime** | Date and time in ISO 8601 format. | [optional] [readonly] 
**amount** | **double** |  | [optional] 
**aria_invoice_id** | **string** |  | [optional] [readonly] 
**client_service_id** | **string** |  | [optional] 
**credit_coupon_code** | **string** |  | [optional] 
**description** | **string** |  | [optional] 
**id** | **string** |  | [optional] 
**line_number** | **int** |  | [optional] 
**plan_name** | **string** |  | [optional] 
**plan_no** | **double** |  | [optional] 
**rate_per_unit** | **double** |  | [optional] 
**rate_schedule_no** | **double** |  | [optional] 
**rate_schedule_tier_no** | **double** |  | [optional] 
**service_name** | **string** |  | [optional] 
**service_no** | **double** |  | [optional] 
**units** | **double** |  | [optional] 
**usage_type_cd** | **string** |  | [optional] 
**usage_type_no** | **double** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> WebService-Fastly-6.02.tar.gz: WebService-Fastly-6.02/docs/BillingResponseLineItem.md <==
# WebService::Fastly::Object::BillingResponseLineItem

## Load the model package
```perl
use WebService::Fastly::Object::BillingResponseLineItem;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_at** | **DateTime** | Date and time in ISO 8601 format. | [optional] [readonly] 
**deleted_at** | **DateTime** | Date and time in ISO 8601 format. | [optional] [readonly] 
**updated_at** | **DateTime** | Date and time in ISO 8601 format. | [optional] [readonly] 
**amount** | **double** |  | [optional] 
**aria_invoice_id** | [**LineItemDataReadOnlyInvoiceId**](LineItemDataReadOnlyInvoiceId.md) |  | [optional] 
**client_service_id** | **string** |  | [optional] 
**credit_coupon_code** | **string** |  | [optional] 
**description** | **string** |  | [optional] 
**id** | **string** |  | [optional] 
**line_number** | **int** |  | [optional] 
**plan_name** | **string** |  | [optional] 
**plan_no** | **double** |  | [optional] 
**rate_per_unit** | **double** |  | [optional] 
**rate_schedule_no** | **double** |  | [optional] 
**rate_schedule_tier_no** | **double** |  | [optional] 
**service_name** | **string** |  | [optional] 
**service_no** | **double** |  | [optional] 
**units** | **double** |  | [optional] 
**usage_type_cd** | **string** |  | [optional] 
**usage_type_no** | **double** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
